@@ -1,6 +1,6 @@
 from drepr.version import __version__
 from drepr.engine import execute, FileOutput, MemoryOutput, OutputFormat
-from drepr.graph import Graph
+from drepr.graph_deprecated import Graph
 from drepr.models import DRepr, DReprBuilder
 from drepr import outputs
 from drepr import models
\ No newline at end of file
