@@ -17,14 +17,14 @@ def get_backends(dataset_dir: Path):
 
 @pytest.fixture()
 def s01(resource_dir):
-    return get_backends(resource_dir / "synthesis_s1")
+    return get_backends(resource_dir / "s01_synthesis")
 
 
 @pytest.fixture()
 def s02(resource_dir):
-    return get_backends(resource_dir / "synthesis_s2")
+    return get_backends(resource_dir / "s02_synthesis")
 
 
 @pytest.fixture()
 def s03(resource_dir):
-    return get_backends(resource_dir / "synthesis_s3")
+    return get_backends(resource_dir / "s03_synthesis")
